/**
 * @file boot_common.h
 * @brief CycloneBOOT Bootloader common functions
 *
 * @section License
 *
 * Copyright (C) 2021-2022 Oryx Embedded SARL. All rights reserved.
 *
 * This file is part of CycloneBOOT Eval.
 *
 * This software is provided in source form for a short-term evaluation only. The
 * evaluation license expires 90 days after the date you first download the software.
 *
 * If you plan to use this software in a commercial product, you are required to
 * purchase a commercial license from Oryx Embedded SARL.
 *
 * After the 90-day evaluation period, you agree to either purchase a commercial
 * license or delete all copies of this software. If you wish to extend the
 * evaluation period, you must contact sales@oryx-embedded.com.
 *
 * This evaluation software is provided "as is" without warranty of any kind.
 * Technical support is available as an option during the evaluation period.
 *
 * @author Oryx Embedded SARL (www.oryx-embedded.com)
 * @version 2.1.0
 **/

#ifndef _BOOT_COMMON_H
#define _BOOT_COMMON_H

//Dependencies
#include "core/slot.h"
#include "core/image.h"
#include "bootloader/boot.h"
#include "error.h"

//Initialization vector size of encrypted images in external flash memory
#define INIT_VECT_SIZE 16

//CycloneBOOT Bootloader common related functions
error_t bootInitPrimaryFlash(BootContext *context, BootSettings *settings);
error_t bootInitSecondaryFlash(BootContext *context, BootSettings *settings);
error_t bootSelectUpdateImageSlot(BootContext *context, SlotDesc **selectedSlot);
error_t bootUpdateApp(BootContext *context, SlotDesc *slot);
error_t bootCheckImage(SlotDesc *slot);
error_t bootGetSlotImgHeader(SlotDesc *slot, ImageHeader *header);
error_t bootCheckSlotAppResetVector(SlotDesc *slot);

#endif //!_BOOT_COMMON_H
