/**
 * @file error.h
 * @brief Error codes description
 *
 * @section License
 *
 * Copyright (C) 2021-2022 Oryx Embedded SARL. All rights reserved.
 *
 * This file is part of CycloneBOOT Eval.
 *
 * This software is provided in source form for a short-term evaluation only. The
 * evaluation license expires 90 days after the date you first download the software.
 *
 * If you plan to use this software in a commercial product, you are required to
 * purchase a commercial license from Oryx Embedded SARL.
 *
 * After the 90-day evaluation period, you agree to either purchase a commercial
 * license or delete all copies of this software. If you wish to extend the
 * evaluation period, you must contact sales@oryx-embedded.com.
 *
 * This evaluation software is provided "as is" without warranty of any kind.
 * Technical support is available as an option during the evaluation period.
 *
 * @author Oryx Embedded SARL (www.oryx-embedded.com)
 * @version 2.1.0
 **/

#ifndef _CBOOT_ERROR_H
#define _CBOOT_ERROR_H

//Dependencies
#include "error.h"

// C++ guard
#ifdef __cplusplus
extern "C"
{
#endif

/**
 * @brief Error codes
 **/

typedef enum
{

    CBOOT_NO_ERROR = ERROR_PARTIAL_MATCH + 1,      ///< CBOOT Success
    CBOOT_ERROR_FAILURE,                           ///< CBOOT error code

    CBOOT_ERROR_INVALID_PARAMETERS,

    CBOOT_ERROR_INVALID_IMAGE_HEADER,
    CBOOT_ERROR_INVALID_IMAGE_CHECK,
    CBOOT_ERROR_MISSING_IMAGE_CHECK_METHOD,
    CBOOT_ERROR_INCOMPATIBLE_IMAGE_APP_VERSION,

    CBOOT_ERROR_INVALID_IMAGE_INTEGRITY_TAG,
    CBOOT_ERROR_INVALID_IMAGE_AUTHENTICATION_TAG,

    CBOOT_ERROR_INVALID_IMAGE_APP,

    CBOOT_ERROR_IMAGE_NOT_READY,

    CBOOT_ERROR_INVALID_STATE,

    CBOOT_ERROR_BUFFER_OVERFLOW,

} cboot_error_t;

// C++ guard
#ifdef __cplusplus
}
#endif

#endif
