/**
 * @file slot.h
 * @brief Slot Memory managment
 *
 * @section License
 *
 * Copyright (C) 2021-2022 Oryx Embedded SARL. All rights reserved.
 *
 * This file is part of CycloneBOOT Eval.
 *
 * This software is provided in source form for a short-term evaluation only. The
 * evaluation license expires 90 days after the date you first download the software.
 *
 * If you plan to use this software in a commercial product, you are required to
 * purchase a commercial license from Oryx Embedded SARL.
 *
 * After the 90-day evaluation period, you agree to either purchase a commercial
 * license or delete all copies of this software. If you wish to extend the
 * evaluation period, you must contact sales@oryx-embedded.com.
 *
 * This evaluation software is provided "as is" without warranty of any kind.
 * Technical support is available as an option during the evaluation period.
 *
 * @author Oryx Embedded SARL (www.oryx-embedded.com)
 * @version 2.1.0
 **/

#ifndef _SLOT_H
#define _SLOT_H

//Dependencies
#include "os_port.h"
#include "error.h"

typedef struct
{
   uint32_t addr;    ///<Slot address
   size_t size;      ///<Slot size
   void *flash;      ///<Pointer to the descriptor of the flash holding the slot
} SlotDesc;

//CycloneBOOT Slot related functions
bool_t isSlotsOverlap(uint32_t addrSlot1, size_t sizeSlot1, uint32_t addrSlot2, size_t sizeSlot2);
bool_t isSlotInBank2(SlotDesc *slot);
bool_t isSlotInExtMem(SlotDesc *slot);
error_t slotRead(SlotDesc *slot, uint32_t offset, uint8_t *buffer, size_t length);
error_t slotErase(SlotDesc *slot);

#endif //!_SLOT_H
