/**
 * @file iap_user_settings.h
 * @brief IAP user settings configuration
 *
 * @section License
 *
 * Copyright (C) 2021-2022 Oryx Embedded SARL. All rights reserved.
 *
 * This file is part of CycloneBOOT Eval.
 *
 * This software is provided in source form for a short-term evaluation only. The
 * evaluation license expires 90 days after the date you first download the software.
 *
 * If you plan to use this software in a commercial product, you are required to
 * purchase a commercial license from Oryx Embedded SARL.
 *
 * After the 90-day evaluation period, you agree to either purchase a commercial
 * license or delete all copies of this software. If you wish to extend the
 * evaluation period, you must contact sales@oryx-embedded.com.
 *
 * This evaluation software is provided "as is" without warranty of any kind.
 * Technical support is available as an option during the evaluation period.
 *
 * @author Oryx Embedded SARL (www.oryx-embedded.com)
 * @version 2.1.0
 **/

#ifndef _IAP_USER_SETTINGS
#define _IAP_USER_SETTINGS

//Dependencies
#include "iap/iap.h"
#include "security/verify.h"
#include "drivers/flash/internal/stm32f4xx_flash_driver.h"

extern const uint8_t* pemIapSignPublicKey;
extern size_t pemIapSignPublicKeyLen;

//IAP signature public key resource path
#define IAP_PUBLIC_SIGN_KEY "keys/rsa_public_key.pem"

//Scenario 1 : Simple app + integrity
#if defined(IAP_SCENARIO_1) || (!(defined(IAP_SCENARIO_1) || defined(IAP_SCENARIO_2) || defined(IAP_SCENARIO_3)))
#define IAP_VERIFY_METHOD           VERIFY_METHOD_INTEGRITY
#define IAP_SETTING_INTEGRITY_ALGO  CRC32_HASH_ALGO
#define IAP_SETTING_AUTH_ALGO       VERIFY_AUTH_NONE
#define IAP_SETTING_AUTH_HASH_ALGO  NULL
#define IAP_SETTING_AUTH_KEY        NULL
#define IAP_SETTING_AUTH_KEY_LEN    0
#define IAP_SETTING_SIGN_ALGO       VERIFY_SIGN_NONE
#define IAP_SETTING_SIGN_HASH_ALGO  NULL
#define IAP_SETTING_SIGN_KEY        NULL
#define IAP_SETTING_SIGN_KEY_LEN    0
#define IAP_SETTING_CIPHER_ALGO     NULL
#define IAP_SETTING_CIPHER_MODE     CIPHER_MODE_NULL
#define IAP_SETTING_CIPHER_KEY      NULL
#define IAP_SETTING_CIHPER_KEY_LEN  0
#endif

//Scenario 2 : Cipher app + authentification
#if defined(IAP_SCENARIO_2)
#define IAP_VERIFY_METHOD           VERIFY_METHOD_AUTHENTICATION
#define IAP_SETTING_INTEGRITY_ALGO  NULL
#define IAP_SETTING_AUTH_ALGO       VERIFY_AUTH_HMAC
#define IAP_SETTING_AUTH_HASH_ALGO  MD5_HASH_ALGO
#define IAP_SETTING_AUTH_KEY        "107b8d4bf62d1c9e26968e8ff51a74df"
#define IAP_SETTING_AUTH_KEY_LEN    32
#define IAP_SETTING_SIGN_ALGO       VERIFY_SIGN_NONE
#define IAP_SETTING_SIGN_HASH_ALGO  NULL
#define IAP_SETTING_SIGN_KEY        NULL
#define IAP_SETTING_SIGN_KEY_LEN    0
#define IAP_SETTING_CIPHER_ALGO     AES_CIPHER_ALGO
#define IAP_SETTING_CIPHER_MODE     CIPHER_MODE_CBC
#define IAP_SETTING_CIPHER_KEY      "aa3ff7d43cc015682c7dfd00de9379e7"
#define IAP_SETTING_CIHPER_KEY_LEN  32
#endif

//Scenario 3 : Cipher app + signature
#if defined(IAP_SCENARIO_3)
#define IAP_VERIFY_METHOD           VERIFY_METHOD_SIGNATURE
#define IAP_SETTING_INTEGRITY_ALGO  NULL
#define IAP_SETTING_AUTH_ALGO       VERIFY_AUTH_NONE
#define IAP_SETTING_AUTH_HASH_ALGO  NULL
#define IAP_SETTING_AUTH_KEY        NULL
#define IAP_SETTING_AUTH_KEY_LEN    0
#define IAP_SETTING_SIGN_ALGO       VERIFY_SIGN_RSA
#define IAP_SETTING_SIGN_HASH_ALGO  SHA256_HASH_ALGO
#define IAP_SETTING_SIGN_KEY        (const char_t*) pemIapSignPublicKey
#define IAP_SETTING_SIGN_KEY_LEN    pemIapSignPublicKeyLen
#define IAP_SETTING_CIPHER_ALGO     AES_CIPHER_ALGO
#define IAP_SETTING_CIPHER_MODE     CIPHER_MODE_CBC
#define IAP_SETTING_CIPHER_KEY      "aa3ff7d43cc015682c7dfd00de9379e7"
#define IAP_SETTING_CIHPER_KEY_LEN  32
#endif

//IAP user settings memory configuration
#define IAP_SETTING_PRM_MEM_DRIVER        &stm32f4xxFlashDriver

#endif //!_IAP_USER_SETTINGS
