 ## Getting started with https_client_iap_dual_bank_demo

This demonstration project provided for the nucleo_f767zi contains a HTTP server and CycloneBOOT IAP middleware. The HTTP server will manage the recepetion of the update image. The CycloneBOOT IAP middleware will manage the processing of the image fetched by the HTTP server.

When you press the user button of the nucleo_f767zi board it trigger an update procedure resulting in downloading an update image from a web server in order to update the current application firmware. To make the update more visual we provide 3 different update images with a specific blinking LED color : RED, GREEN or BLUE (it depends of the board). The update image selected to be downloaded follows a specific cycle:
- RED blinking LED image downloads GREEN blinking LED image
- GREEN blinking LED image downloads BLUE blinking LED image
- BLUE blinking LED image downloads RED blinking LED image

> Note: The board may only have one LED available. Which means you won't be able to see a change of blinking LED color. In that case you, have a look to the greeting message in the trace logs (i.e serial console). You will see the current application firmware version following by the LED color : `Version: X.X.X (<led-color>)`

This demo makes use of the MCU flash dual bank functionnality. One bank holds the current application firmware while the other bank serve to store the new application firmware. This new application firmware comes from an update image. If the update process is successful (image is valid) then a swap between the two flash banks will be performed to boot to the new firmware.

It contains several update scenarios: 

- scenario 1 : plaintext firmware + integrity (CRC32)
- scenario 2 : cipher firmware + authentication (AES-CBC + HMAC-MD5)
- scenario 3 : cipher firmware + signature (AES-CBC + RSA-SHA256)
  
For this demonstration, a web server that you can access to upload an update image is a prerequisite. You can specify your web server by editing several macros in the file `http_user.c` in  `nucleo_f767zi\https_client_iap_dual_bank_demo\src` directory. 

Here is an example if you want to download an update image from the Oryx Web Server:

```c
//Application configuration
//HTTPS Web Server hostname
#define APP_HTTP_SERVER_NAME "www.oryx-enc-algombedded.com"
//HTTPS Web Server port
#define APP_HTTP_SERVER_PORT 443

...

//Update image uri path
#define APP_HTTP_URI "<update-image-uri>"
```

> Note: This demo is configured to use the Oryx Web Server `www.oryx-enc-algombedded.com` on port `443`. 

### Step #0 : Prerequisites 

  - Download and install STLink Utility : https://www.st.com/en/development-tools/stsw-link004.html.
Make sure to add the ST-LINK_CLI.exe in to your PATH.
Note: You can also use the newer STM32CubeProgrammer as well.
However, please refer to its documentation to learn more on
how to adapt the following steps to use that software.

### Step #1 : Board configuration

In this step, we will configure the nucleo_f767zi MCU to accept our project(s). Especially the MCU will be configured to run in dual bank mode (dual flash bank).

Plug the nucleo_f767zi to your computer.

**Manual method**: 

Run the following commands (making sure ST-LINK_CLI.exe is in your PATH): `ST-LINK_CLI.exe -c ID=0 SWD -OB nDBANK=0 nDBOOT=0 BOOT_ADD0=0x2000 BOOT_ADD1=0x2040`

**Using the provided script**:

1. Navigate to `nucleo_f767zi/https_client_iap_dual_bank_demo/scripts` directory.
2. Run the `configure_dual_bank_mode.bat` script.
3. Your board is now ready.

### Step #2 : Generate demo firmware binaries

1. Open the https_client_iap_dual_bank_demo project : `nucleo_f767zi/https_client_iap_dual_bank_demo/keil/https_client_iap_dual_bank_demo.uvprojx`
2. Depending the choosen scenario, select the corresponding compilation profile. It can be one of these profile:
    - `scenario_1_simple_app_and_integrity`
    - `scenario_2_cipher_app_and_authentication`
    - `scenario_3_cipher_app_and_signature`
3. Clean then Build or Recompile the project
4. You should see this binary file `https_client_iap_dual_bank_demo.bin` in `nucleo_f767zi\https_client_iap_dual_bank_demo` directory

> Note: 
> - The scenario choosed for the compilation will reflect the type of image that CycloneBOOT IAP middleware will be able to manage.
> - If you want to change the scenario you MUST recompile the demo selecting the corresponding compilation profile 


### Step #3 : Load initial firmware in to flash

Once the application firmware generated you need to load it in to the first flash bank at address `0x08000000`.

You can perform this step either manually or by running the provided script.

**Manual Method** :

Several options are available:
- Use you favorite IDE to load the firmware generated in *Step #2* (for ex Keil)
- Or use STLink Utility with this command : `ST-LINK_CLI.exe -c ID=0 SWD -Halt -Rst -P ..\https_client_iap_dual_bank_demo\https_client_iap_dual_bank_demo.bin 0x08000000`

**Using the provided script** :

Run `load_https_client_iap_dual_bank_demo.bat` in `../scripts` directory.

> **Important**: Make SURE that the MCU is running on the first flash bank before to load the firmware binary. If it is not the case then configure again the board as explained in *Step #1*.


### Step #4 : Generate demo firmware image updates

This step will transform the binary generated (at *Step #3*) in to an image file recognizable by CycloneBOOT. Regarding the choosen scenario used to build the current running firmware, the application will be expecting an update image generated for the same scenario.

Have a look to the function `httpUserUpdate()` in the `nucleo_f767zi\https_client_iap_single_bank_demo\src\http_user.c` file to know which settings has been used to configure CycloneBOOT IAP in the demo application. These settings MUST match the options specified to generate the update image in regards to the choosen scenario. 

You can perform these steps either manually or by running the provided script. 

**Manual Method** : 

From within the demo project directory, execute the following command for:
- Scenario 1: `..\..\..\..\..\utils\AppImageBuilder\bin\app_image_builder_windows.exe --input https_client_iap_dual_bank_demo.bin --output https_client_iap_dual_bank_demo_image_scenario_1.img --firmware-version X.X.X --integrity-algo crc32`
- Scenario 2: `..\..\..\..\..\utils\AppImageBuilder\bin\app_image_builder_windows.exe --input https_client_iap_dual_bank_demo.bin --output https_client_iap_dual_bank_demo_image_scenario_2.img --firmware-version X.X.X --enc-algo aes-cbc --enc-algo aa3ff7d43cc015682c7dfd00de9379e7 --auth-algo hmac-md5 --auth-key 107b8d4bf62d1c9e26968e8ff51a74df`
- Scenario 3: `..\..\..\..\..\utils\AppImageBuilder\bin\app_image_builder_windows.exe --input https_client_iap_dual_bank_demo.bin --output https_client_iap_dual_bank_demo_image_scenario_3.img --firmware-version X.X.X --enc-algo aes-cbc --enc-algo aa3ff7d43cc015682c7dfd00de9379e7 --sign-algo rsa-sha256 --sign-key ../../https_client_iap_dual_bank_demo/resources/keys/rsa_private_key.pem`


**Using the provided script** :

Run `generate_https_client_iap_dual_bank_images.bat` in `../scripts` directory

- It will produce 3 images from the https_client_iap_dual_bank_demo.bin` binary file, one for each scenario:
    - https_client_iap_dual_bank_demo_image_scenario_1.img
    - https_client_iap_dual_bank_demo_image_scenario_2.img
    - https_client_iap_dual_bank_demo_image_scenario_3.img

Those images are generated in `../scripts` directory.

> Note: The *`--firmware-version X.X.X`* command line option serves to indicate the version of the firmware application binary. You are free to specify another version.

### Step #5 : Test the Demo

**Note: Remember that the demo expects a specific scenario that has been chosen and the update image MUST also match that scenario.**

1. If not already done configure the board in dual bank mode as explained in *Step #1* (only needed for MCU that support dual bank flash), else skip this step.
2. If not already done compile the demo for the choosen scenario as explained in *Step #2*, else skip this step.
3. Load the demo firmware binary into flash at `0x08000000` as explained in *Step #3*.
4. Generate firmware update image as explained in *Step #4* in regards of the choosen scenario.
5. Open your favorite serial console (115200 bauds). 
6. Click on the reset button to restart the demo.
7. Connect the board to a router with an Ethernet cable.
8. You should be able read to the IP address of the board along with a welcome message and the red LED (LD3) should be blinking.
9. Click on the User Button (B1 USER) to initiate a firmware update.
10. If no error occurs during the reception of the image, the device will update and reboot.
11. With the new update, the green LED (LD1) shoud be blinking.
12. You can reproduce the step *10.* to *14.* to trigger another update. 

> Note: If you want to test another scenario restart from step *1.*