## Getting started with uart_ymodem_iap_dual_bank_demo

This demonstration project provided for the nucleo_h7a3zi_q contains a UART Ymodem(1k) and CycloneBOOT IAP middleware. The Ymodem(1k) protocol will manage the recepetion of the update image. The CycloneBOOT IAP middleware will manage the processing of the image fetched by the Ymodem(1k) protocol.

This demo makes use of the MCU flash dual bank functionnality. One bank holds the current application firmware while the other bank serve to store the new application firmware. This new application firmware comes from an update image. If the update process is successful (image is valid) then a swap between the two flash banks will be performed to boot to the new firmware.

The demo requires the use of serial console that manages ymodem protocol (as Tera-Term) to send the update image to the nucleo_h7a3zi_q. The serial console uses the virtual com port (`USART3` -> `USB CN1`) of the board with a baudrate of `115200`. When the board starts there will be a prompt message in the console that invites you to enter:
- Either `1` to start the reception of the update image
- Or `2` to display the version of the current application 

If you enter `1` then you will need to send the update image using ymodem protocol. For exemple with with Tera-Term you need to click `File > Transfer > YMODEM > Send ...` and select the update image to be send.

To make the update more visual we provide 3 different update images with a specific blinking LED color : RED, GREEN or BLUE (it depends of the board).

It contains several update scenarios: 

- scenario 1 : plaintext firmware + integrity (CRC32)
- scenario 2 : cipher firmware + authentication (AES-CBC + HMAC-MD5)
- scenario 3 : cipher firmware + signature (AES-CBC + RSA-SHA256)

Here is an example if you want to generate an application firmware with the `green` version. First open the `src/main.h` header file and then edit it as follow:

```c
...

//Uncomment one of the folliwng lines to select the app version
//#define APP_RED_VERSION       //RED LED version -> v1.0.0
#define APP_GREEN_VERSION     //GREEN LED version -> v2.0.0         //Uncomment this line to generate the green version application
//#define APP_YELLOW_VERSION    //YELLOW LED version -> v3.0.0
```

> Note: Per default the version is `v1.0.0` and the color is `RED`.

> Notes: To get more trace information you can plug a USB TTL-232R adapter between your computer and the USART2:
> - TX signal : PD5 -> CN9:6 pin
> - RX signal : PD6 -> CN9:5 pin
> - Baudrate : 9600

### Step #0 : Prerequisites 

  - Download and install STM32CubeProgrammer : https://www.st.com/en/development-tools/stm32cubeprog.html.
Make sure to add the STM32_Programmer_CLI.exe in to your PATH.
  - Download and install TeraTerm : https://osdn.net/projects/ttssh2/releases/.

### Step #1 : Board configuration

In this step, we will configure the nucleo_h7a3zi_q MCU to accept our project(s). Especially the MCU will be configured to run in dual bank mode (dual flash bank).

Plug the nucleo_h7a3zi_q to your computer.

**Manual method**: 

Run the following commands (making sure STM32_Programmer_CLI.exe is in your PATH):
`STM32_Programmer_CLI.exe -c port=SWD index=0 -ob SWAP_BANK_OPT=0 BOOT_CM7_ADD0=0x0800`

**Using the provided script**:

1. Navigate to `nucleo_h7a3zi_q/uart_ymodem_iap_dual_bank_demo/scripts` directory.
2. Run the `configure_dual_bank_mode.bat` script.
3. Your board is now ready.

### Step #2 : Generate demo firmware binaries

1. Open the uart_ymodem_iap_dual_bank_demo project : `nucleo_h7a3zi_q/uart_ymodem_iap_dual_bank_demo/keil/uart_ymodem_iap_dual_bank_demo.uvprojx`
2. Depending the choosen scenario, select the corresponding compilation profile. It can be one of these profile:
    - `scenario_1_simple_app_and_integrity`
    - `scenario_2_cipher_app_and_authentication`
    - `scenario_3_cipher_app_and_signature`
3. Clean then Build or Recompile the project
4. You should see this binary file `uart_ymodem_iap_dual_bank_demo.bin` in `nucleo_h7a3zi_q\uart_ymodem_iap_dual_bank_demo` directory

> **Tips:** You can change the version and the blinking led color of the demo application before compilation, as explained at the begining of this readme.

> Note: 
> - The scenario choosed for the compilation will reflect the type of image that CycloneBOOT IAP middleware will be able to manage.
> - If you want to change the scenario you MUST recompile the demo selecting the corresponding compilation profile  

### Step #3 : Load initial firmware in to flash

Once the application firmware generated you need to load it in to the first flash bank at address `0x08000000`.

You can perform this step either manually or by running the provided script.

**Manual Method** :

Several options are available:
- Use you favorite IDE to load the firmware generated in *Step #2* (for ex Keil)
- Or use STM32CubeProgrammer with this command : `STM32_Programmer_CLI.exe -c port=SWD index=0 -d ..\uart_ymodem_iap_dual_bank_demo\uart_ymodem_iap_dual_bank_demo.bin 0x08000000 -halt -rst`

**Using the provided script** :

Run `load_uart_ymodem_iap_dual_bank_demo.bat` in `../scripts` directory.

> **Important**: Make SURE that the MCU is running on the first flash bank before to load the firmware binary. If it is not the case then configure again the board as explained in *Step #1*.

### Step #4 : Generate demo firmware image updates

This step will transform the binary generated (at *Step #3*) in to an image file recognizable by CycloneBOOT. Regarding the choosen scenario used to build the current running firmware, the application will be expecting an update image generated for the same scenario.

Have a look to the function `uartUserDownload()` in the `nucleo_h7a3zi_q\uart_ymodem_iap_dual_bank_demo\src\uart_user.c` file to know which settings has been used to configure CycloneBOOT IAP in the demo application. These settings MUST match the options specified to generate the update image in regards to the choosen scenario.

You can perform these steps either manually or by running the provided script. 

**Manual Method** : 

From within the demo project directory, execute the following command for:
- Scenario 1: `..\..\..\..\..\utils\AppImageBuilder\bin\app_image_builder_windows.exe --input uart_ymodem_iap_dual_bank_demo.bin --output uart_ymodem_iap_dual_bank_demo_image_scenario_1.img --firmware-version X.X.X --integrity-algo crc32`
- Scenario 2: `..\..\..\..\..\utils\AppImageBuilder\bin\app_image_builder_windows.exe --input uart_ymodem_iap_dual_bank_demo.bin --output uart_ymodem_iap_dual_bank_demo_image_scenario_2.img --firmware-version X.X.X --enc-algo aes-cbc --enc-algo aa3ff7d43cc015682c7dfd00de9379e7 --auth-algo hmac-md5 --auth-key 107b8d4bf62d1c9e26968e8ff51a74df`
- Scenario 3: `..\..\..\..\..\utils\AppImageBuilder\bin\app_image_builder_windows.exe --input uart_ymodem_iap_dual_bank_demo.bin --output uart_ymodem_iap_dual_bank_demo_image_scenario_3.img --firmware-version X.X.X --enc-algo aes-cbc --enc-algo aa3ff7d43cc015682c7dfd00de9379e7 --sign-algo rsa-sha256 --sign-key ../../uart_ymodem_iap_dual_bank_demo/resources/keys/rsa_private_key.pem`


**Using the provided script** :

Run `generate_uart_ymodem_iap_dual_bank_images.bat` in `../scripts` directory

- It will produce 3 images from the uart_ymodem_iap_dual_bank_demo.bin` binary file, one for each scenario:
    - uart_ymodem_iap_dual_bank_demo_image_scenario_1.img
    - uart_ymodem_iap_dual_bank_demo_image_scenario_2.img
    - uart_ymodem_iap_dual_bank_demo_image_scenario_3.img

Those images are generated in `../scripts` directory.

> Note: The *`--firmware-version X.X.X`* command line option serves to indicate the version of the firmware application binary. You are free to specify another version.

### Step #5 : Test the Demo

**Note: Remember that the demo expects a specific scenario that has been chosen and the update image MUST also match that scenario.**

1. If not already done configure the board in dual bank mode as explained in *Step #1* (only needed for MCU that support dual bank flash), else skip this step.
2. If not already done compile the demo for the choosen scenario as explained in *Step #2*, else skip this step.
3. Load the demo firmware binary into flash at `0x08000000` as explained in *Step #3*.
4. Generate firmware update image as explained in *Step #4* in regards of the choosen scenario.
5. Open the TeraTerm serial console (115200 bauds). 
6. Click on the reset button to restart the demo.
7. On the reception of the prompt message enter `2` to get the current version of the application.
8. Then enter `1` to start the reception of a firmware update image.
9. In TeraTerm send the generated firmware update image from step *4.* using Ymodem(1k) by clicking on `File > Transfer > YMODEM > Send ...`.
    If the update process is OK then the board will automatically reboot.
10. You shoud get a blinking led color that match the version color chosen for the new application.
11. You can check the version of the new application by redoing step *7.* just above.
11. You can reproduce the step *8.* to *11.* by adapting the image file.

> **Tips:** You can also redo step *2.* followed by step *4.* to change the version color of the application. This way you will be able to see the blinking led color change at each update (step *8.* to *11.*).  

> Note: If you want to test another scenario restart from step *1.*